==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>A gravação de vídeo está em andamento. Fechar a janela?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Você não tem permissão para operar esta pasta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Pasta inválida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Localização do arquivo</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Disparar</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Modo sequencial</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Atrasar temporizador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de saída</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pçs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pçs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>O Câmera é um utilitário para capturar imagens e vídeos pela webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Arquivo não salvo</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Salvar em:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Configurações da resolução</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolução:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Tirar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Gravar vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Parar de tirar fotos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenhuma webcam encontrada</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>A webcam está em uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Parar gravação</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>A gravação de vídeo está em andamento. Fechar a janela?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Você não tem permissão para operar esta pasta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Pasta inválida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir pasta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Localização do arquivo</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Disparar</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Modo sequencial</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Atrasar temporizador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de saída</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pçs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pçs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>O Câmera é um utilitário para capturar imagens e vídeos pela webcam.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Arquivo não salvo</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Salvar em:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Configurações da resolução</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolução:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vídeos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efeitos sonoros</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Câmera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interromper a gravação</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Exibir atalhos</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interromper a captura de fotos</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu de contexto</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Capturar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Gravar vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interromper a captura de fotos</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenhuma webcam encontrada</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>A webcam está em uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interromper a gravação</translation>
    </message>
</context>
</TS>
